==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/moderate.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

if ($login && $user['user_level'] == 1) {
settype($what, "string");
if ($what=="verify" && $rid) {
	$sql = "UPDATE T_Stories SET Verified = 'Y' WHERE Rid = '$rid'";
	if (SqlQuery($sql)) {
		moder_log($user['uid'], _VERIFY_STORY . " $rid");
		if ($CONF["Backend"]) KWL_ExportRdf();
	}
	KWL_Redirect("moderate.php");
	exit;
	
} elseif ($what=="kill" && $rid) {
	$sql = "DELETE FROM T_Stories WHERE Rid = '$rid'";
	if (SqlQuery($sql)) moder_log($user['uid'], _DEL_STORY . " $rid");
	KWL_Redirect("moderate.php");
	exit;

} elseif ($what=="edit" && $rid) {
	moder_log($user['uid'], _EDIT . " $rid");
	$head = _EDIT;
	include("include/header.inc.php");
	$sql  = "SELECT * FROM T_Stories WHERE Rid = '$rid' ";
	$A = SqlQueryFetchArray($sql);

	if (!$A) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br />" . _NOSTORY . "<br /><br />";
		KWL_DrawMain($VAR);
	} else {
   $out = new KWL_Html;
	$VAR['Heading'] = _EDIT;

$VAR["Content"] = $out->form_start("edit.php","Edit",$CONF['FILE_UPLOAD']) . 
   $out->table_start("100%",'',0,0,3) ."
<tr>
	<td>* ". _AUTHOR . ":</td>
	<td>". $out->input_form("text","Author",$A['Author'],$size['name'],32) ."</TD>
</tr>
<tr>
	<td>* " . _EMAIL . ":</td>
	<td>". $out->input_form("text","AuthorEmail",$A['AuthorEmail'],$size['name'],96) ."</td>
</tr>
<tr>
	<td>" . _URL . ":</td>
	<td>". $out->input_form("text","AuthorURL",$A['AuthorURL'],$size['name'],96) ."</td>
</tr>
<tr>
	<td>* " . _TITLE . ":</td>
	<td>". $out->input_form("text","Heading",$A['Heading'],$size['titl'],96) ."</td>
</tr>";

if ($CONF["Topics"]) {
$VAR["Content"] .= "
<tr>
	<td>". _TOPIC . ":</td>
	<td>". $out->topicsel($A["Topic"],"post") ."
</tr>";
} else {
	$VAR["Content"] .= "<input type=\"hidden\" name=\"Topic\" value=\"$A[Topic]\">\n";
}
	
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">". _SUMMARY . ":
	<br />". $out->textarea("Summary",5,$size['text'],KWL_PrepareHtml($A['Summary'])) ."</td>
</tr>
<tr>
	<td colspan=\"2\">* ". _STORY .": ". KWL_FormResizer("Edit.Content",$size['text'],10) ."
	<br />". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml($A['Content'])) ."</td>
</tr>
<tr>
   <td colspan=\"2\">". KWL_MakeSelectParse($CONF['story_parse'],$A['ParseLevel']) ."
   </td>
</tr>\n";

if ($CONF['EmailComments']) {
   $VAR["Content"] .= "<tr>
      <td colspan=\"2\">". $out->check_box("EmailComments",$A['EmailComments']) ." ". _MAILCOMMENTS . "</td>
</tr>";
}

if (SqlCount("T_IndexNames")) {
   $VAR["Content"] .= KWL_EditIndex($A["Rid"]);
}

$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">"
   . $out->input_form("HIDDEN","oldtopic",$A['Topic'])
   . $out->input_form("HIDDEN","oldfile",$A['bcfile'])
   . $out->input_form("HIDDEN","story",$A['Rid'])
   . $out->input_form("HIDDEN","return","moderate.php")
   . $out->input_form("HIDDEN","mode","estory")
   . $out->input_form("SUBMIT",'',_EDIT) ."</td>
</tr>". $out->table_end() . $out->form_end();
	KWL_DrawMain($VAR);
}

} else {
	include("include/header.inc.php");
		$sql  = "SELECT * FROM T_Stories ";
		$sql .= "WHERE Verified != 'Y' ORDER BY Birthstamp ASC";
		$result	= SqlQuery($sql);
		$nrows	= mysql_num_rows($result);
	
		if ($nrows) {
		   $VAR["Heading"] = _SMODER;
			$VAR["Content"] = _NEWSTORY ." ". $nrows . _FIX ."<br />";
			KWL_DrawMain($VAR);
			echo "<br />";
			while ($A = mysql_fetch_array($result)) {
				$CONF['ENABLE_EDIT'] = 0;
				KWL_DrawStory($A);
				echo "<table width=\"100%\"><tr><td align=right>
				<a href=\"$G_URL/moderate.php?what=verify&rid=$A[Rid]\"><img src=\"$CONF[img_url]/verify.gif\" BORDER=\"0\"></a>&nbsp;&nbsp;";
				echo "<a href=\"$G_URL/moderate.php?what=edit&rid=$A[Rid]\"><img src=\"$CONF[img_url]/edit.gif\" BORDER=\"0\"></a>&nbsp;&nbsp;";
				echo "<a onclick=\"return getconfirm();\" href=\"$G_URL/moderate.php?what=kill&rid=$A[Rid]\"><img src=\"$CONF[img_url]/kill.gif\" BORDER=\"0\"></a>";
				echo "</td></tr></table>";
			}
		} else {
			$VAR['Heading'] = _SMODER;
         $VAR['Content'] = "<br /><center><b>". _NONEWSTORY
                        ."</b><p />[ <a href=\"$G_URL\">"
                        . KWL_PrepareHtml($CONF['SiteName']) ."</a> - "
                        . KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</center><br />";
			KWL_DrawMain($VAR);
		}
	}
} else KWL_Redirect("login.php");
include("include/footer.inc.php");

function moder_log($mid,$action) {
	$sql = "INSERT INTO moderatorlog VALUES ('','$mid',now(),'$action')";
	SqlQuery($sql);
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/moderate.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

if ($login && $user['user_level'] == 1) {
settype($what, "string");
if ($what=="verify" && $rid) {
	$sql = "UPDATE T_Stories SET Verified = 'Y' WHERE Rid = '$rid'";
	if (SqlQuery($sql)) {
		moder_log($user['uid'], _VERIFY_STORY . " $rid");
		if ($CONF["Backend"]) KWL_ExportRss();
	}
	KWL_Redirect("moderate.php");
	exit;
	
} elseif ($what=="kill" && $rid) {
	$sql = "DELETE FROM T_Stories WHERE Rid = '$rid'";
	if (SqlQuery($sql)) moder_log($user['uid'], _DEL_STORY . " $rid");
	KWL_Redirect("moderate.php");
	exit;

} elseif ($what=="edit" && $rid) {
	moder_log($user['uid'], _EDIT . " $rid");
	$head = _EDIT;
	include("include/header.inc.php");
	$sql  = "SELECT * FROM T_Stories WHERE Rid = '$rid' ";
	$A = SqlQueryFetchArray($sql);

	if (!$A) {
		$VAR["Heading"] = _NOSTORY;
		$VAR["Content"] = "<br />" . _NOSTORY . "<br /><br />";
		KWL_DrawMain($VAR);
	} else {
   $out = new KWL_Html;
	$VAR['Heading'] = _EDIT;

$VAR["Content"] = $out->form_start("edit.php","Edit",$CONF['FILE_UPLOAD']) . 
   $out->table_start("100%",'',0,0,3) ."
<tr>
	<td>* ". _AUTHOR . ":</td>
	<td>". $out->input_form("text","Author",$A['Author'],$size['name'],32) ."</TD>
</tr>
<tr>
	<td>* " . _EMAIL . ":</td>
	<td>". $out->input_form("text","AuthorEmail",$A['AuthorEmail'],$size['name'],96) ."</td>
</tr>
<tr>
	<td>" . _URL . ":</td>
	<td>". $out->input_form("text","AuthorURL",$A['AuthorURL'],$size['name'],96) ."</td>
</tr>
<tr>
	<td>* " . _TITLE . ":</td>
	<td>". $out->input_form("text","Heading",$A['Heading'],$size['titl'],96) ."</td>
</tr>";

if ($CONF["Topics"]) {
$VAR["Content"] .= "
<tr>
	<td>". _TOPIC . ":</td>
	<td>". $out->topicsel($A["Topic"],"post") ."
</tr>";
} else {
	$VAR["Content"] .= "<input type=\"hidden\" name=\"Topic\" value=\"$A[Topic]\">\n";
}
	
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">". _SUMMARY . ":
	<br />". $out->textarea("Summary",5,$size['text'],KWL_PrepareHtml($A['Summary'])) ."</td>
</tr>
<tr>
	<td colspan=\"2\">* ". _STORY .": ". KWL_FormResizer("Edit.Content",$size['text'],10) ."
	<br />". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml($A['Content'])) ."</td>
</tr>
<tr>
   <td colspan=\"2\">". KWL_MakeSelectParse($CONF['story_parse'],$A['ParseLevel']) ."
   </td>
</tr>\n";

if ($CONF['EmailComments']) {
   $VAR["Content"] .= "<tr>
      <td colspan=\"2\">". $out->check_box("EmailComments",$A['EmailComments']) ." ". _MAILCOMMENTS . "</td>
</tr>";
}

if (SqlCount("T_IndexNames")) {
   $VAR["Content"] .= KWL_EditIndex($A["Rid"]);
}

$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">"
   . $out->input_form("HIDDEN","oldtopic",$A['Topic'])
   . $out->input_form("HIDDEN","oldfile",$A['bcfile'])
   . $out->input_form("HIDDEN","story",$A['Rid'])
   . $out->input_form("HIDDEN","return","moderate.php")
   . $out->input_form("HIDDEN","mode","estory")
   . $out->input_form("SUBMIT",'',_EDIT) ."</td>
</tr>". $out->table_end() . $out->form_end();
	KWL_DrawMain($VAR);
}

} else {
	include("include/header.inc.php");
		$sql  = "SELECT * FROM T_Stories ";
		$sql .= "WHERE Verified != 'Y' ORDER BY Birthstamp ASC";
		$result	= SqlQuery($sql);
		$nrows	= mysql_num_rows($result);
	
		if ($nrows) {
		   $VAR["Heading"] = _SMODER;
			$VAR["Content"] = _NEWSTORY ." ". $nrows . _FIX ."<br />";
			KWL_DrawMain($VAR);
			echo "<br />";
			while ($A = mysql_fetch_array($result)) {
				$CONF['ENABLE_EDIT'] = 0;
				KWL_DrawStory($A);
				echo "<table width=\"100%\"><tr><td align=right>
				<a href=\"$G_URL/moderate.php?what=verify&rid=$A[Rid]\"><img src=\"$CONF[img_url]/verify.gif\" BORDER=\"0\"></a>&nbsp;&nbsp;";
				echo "<a href=\"$G_URL/moderate.php?what=edit&rid=$A[Rid]\"><img src=\"$CONF[img_url]/edit.gif\" BORDER=\"0\"></a>&nbsp;&nbsp;";
				echo "<a onclick=\"return getconfirm();\" href=\"$G_URL/moderate.php?what=kill&rid=$A[Rid]\"><img src=\"$CONF[img_url]/kill.gif\" BORDER=\"0\"></a>";
				echo "</td></tr></table>";
			}
		} else {
			$VAR['Heading'] = _SMODER;
         $VAR['Content'] = "<br /><center><b>". _NONEWSTORY
                        ."</b><p />[ <a href=\"$G_URL\">"
                        . KWL_PrepareHtml($CONF['SiteName']) ."</a> - "
                        . KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</center><br />";
			KWL_DrawMain($VAR);
		}
	}
} else KWL_Redirect("login.php");
include("include/footer.inc.php");

function moder_log($mid,$action) {
	$sql = "INSERT INTO moderatorlog VALUES ('','$mid',now(),'$action')";
	SqlQuery($sql);
}
?>
